<?php
/**
 * File for Custom Services
 *
 * @category Wordpress
 * @package  Sharedaddy
 */

/**
 * Class for Google+1
 *
 * Implementeation of Google+1 Service for Sharedaddy
 *
 * @category Wordpress
 * @package  Sharedaddy
 * @author Marco Neumann <webcoder_at_binware_dot_org>
 * @copyright Copyright (c) 2011, Marco Neumann
 * Licensed under the GNU GPLv3. 
 *
 */
class Share_GooglePlusOne extends Sharing_Advanced_Source
{
    /**
     * Button Size
     *
     * @var String
     */
    private $_size = 'small';

    /**
     * Button Language
     *
     * @var String
     */
    private $_language = 'en-US';

    /**
     * Button with count?
     *
     * @var String
     */
    private $_count = 'true';

    // Configuration extracted from http://code.google.com/apis/+1button/#configuration
    /**
     * Available sizes
     *
     * @var Array
     */
    private $_optionsSize = array(
        'small'    => 'Small Size',
        'medium'   => 'Medium Size',
        'standard' => 'Standard Size',
        'tall'     => 'Tall Size'
    );

    /**
     * Available languages
     *
     * @var Array
     */
    private $_optionsLanguage = array(
        'ar'     => 'Arabic',
        'bg'     => 'Bulgarian',
        'ca'     => 'Catalan',
        'zh-CN'  => 'Chinese (Simplified)',
        'zh-TW'  => 'Chinese (Traditional)',
        'hr'     => 'Croatian',
        'cs'     => 'Czech',
        'da'     => 'Danish',
        'nl'     => 'Dutch',
        'en-GB'  => 'English (UK)',
        'en-US'  => 'English (US)',
        'et'     => 'Estonian',
        'fil'    => 'Filipino',
        'fi'     => 'Finnish',
        'fr'     => 'French',
        'de'     => 'German',
        'el'     => 'Greek',
        'iw'     => 'Hebrew',
        'hi'     => 'Hindi',
        'hu'     => 'Hungarian',
        'id'     => 'Indonesian',
        'it'     => 'Italian',
        'ja'     => 'Japanese',
        'ko'     => 'Korean',
        'lv'     => 'Latvian',
        'lt'     => 'Lithuanian',
        'ms'     => 'Malay',
        'no'     => 'Norwegian',
        'fa'     => 'Persian',
        'pl'     => 'Polish',
        'pt-BR'  => 'Portuguese (Brazil)',
        'pt-PT'  => 'Portuguese (Portugal)',
        'ro'     => 'Romanian',
        'ru'     => 'Russian',
        'sr'     => 'Serbian',
        'sk'     => 'Slovak',
        'sl'     => 'Slovenian',
        'es'     => 'Spanish',
        'es-419' => 'Spanish (Latin America)',
        'sv'     => 'Swedish',
        'th'     => 'Thai',
        'tr'     => 'Turkish',
        'uk'     => 'Ukrainian',
        'vi'     => 'Vietnamese'
    );

    /**
     * Constructor
     *
     * @param Integer $id
     * @param Array $settings
     */
    public function __construct($id, array $settings)
    {
        parent::__construct($id, $settings);
        
        if (isset($settings['size'])) {
            $this->_size = $settings['size'];
        }
        if (isset($settings['language'])) {
            $this->_language = $settings['language'];
        }
        if (isset($settings['count'])) {
            $this->_count = $settings['count'];
        }
    }

    /**
     * Get Service Name
     *
     * @return String
     */
    public function get_name()
    {
        return __('Google +1', 'sharedaddy');
    }

    /**
     * Displays preview
     *
     * @return Share_GooglePlusOne
     */
    public function display_preview()
    {
?>
    <div class="option option-smart-<?php echo $this->_count; ?>"> 
        <?php
            if ($this->button_style == 'text' || $this->button_style == 'icon-text') {
                echo $this->get_name();
            } else {
               echo '&nbsp;';
            }    
        ?>   
    </div>
<?php

        return $this;
    }    

    /**
     * Loads Service required footer code
     *
     * @return Share_GooglePlusOne
     */
    public function display_footer()
    {
        // Load JS for Google +1
        global $post;

        if (isset($post->ID) && $post->ID > 0) {
            $options = array(
                'lang' => $this->_language
            );

            echo '<script type="text/javascript" src="http://apis.google.com/js/plusone.js">';
            if (!empty($options)) {
                echo json_encode($options);
            }
            echo '</script>';
        }

        return $this;
    }

    /**
     * Shows icon
     *
     * @return String
     */
    public function get_display($post)
    {
        return '<g:plusone size="' . $this->_size . '" count="' . $this->_count . '"></g:plusone>';
    }

    /**
     * Displays available Service options
     *
     * @return Share_GooglePlusOne
     */
    public function display_options()
    {
?>
<div class="input">
    <label>
        <select name="size">
            <?php foreach ($this->_optionsSize as $value=>$name): ?>
                <option value="<?php echo $value; ?>"<?php if ($this->_size == $value): ?> selected="selected"<?php endif; ?>><?php _e($name, 'sharedaddy'); ?>
            <?php endforeach; ?>
        </select>
    </label>
    <label>
        <select name="language">
            <?php foreach ($this->_optionsLanguage as $value=>$name): ?>
                <option value="<?php echo $value; ?>"<?php if ($this->_language == $value): ?> selected="selected"<?php endif; ?>><?php _e($name, 'sharedaddy'); ?>
            <?php endforeach; ?>
        </select>
    </label>
    <label>
        <input type="checkbox"<?php if ($this->_count == 'true') { echo ' checked="checked"'; } ?> name="count" /> Show Count
    </label>
</div>
<?php

        return $this;
    }

    /**
     * Updates submitted options
     *
     * @return Share_GooglePlusOne
     */
    public function update_options(array $data)
    {
        if (isset($data['size']) && isset($this->_optionsSize[$data['size']])) {
            $this->_size = $data['size'];
        }

        if (isset($data['language']) && isset($this->_optionsLanguage[$data['language']])) {
            $this->_language = $data['language'];
        }

        $this->_count = ($data['count'])?'true':'false';

        return $this;
    }

    /**
     * Returns current options
     *
     * @var Array
     */
    public function get_options()
    {
        return array(
            'size'     => $this->_size,
            'language' => $this->_language,
            'count'    => $this->_count
        );
    }
}
